@@ -1,6 +1,7 @@
 import requests
 
 import hoopoe.constants as constants
+from hoopoe.utils import handle_response
 
 class Hoopoe:
     def __init__(self, api_key, version, base_url=constants.base_url):
@@ -15,7 +16,7 @@ class Hoopoe:
         self.session = requests.Session()
         self.session.headers.update(
             {
-                "X-API-Key": "Bearer {}".format(self.api_key),
+                "X-API-Key": "{}".format(self.api_key),
                 "Accept": "application/json",
                 "Content-Type": "application/json",
             }
@@ -24,9 +25,9 @@ class Hoopoe:
     def timestamp(self):
         url = f"{self.base_url}/v{self.version}/timestamp/"
         response = self.session.get(url)
-        print(url, response)
-        return response.json()
 
+        return handle_response(response)
+        
     def upupa(self, message, extra={}):
         url = f"{self.base_url}/v{self.version}/upupa/"
         data = {
@@ -34,4 +35,5 @@ class Hoopoe:
             "extra": extra,
         }
         response = self.session.post(url, json=data)
-        return response.json()
+        
+        return handle_response(response)
\ No newline at end of file
